pub struct WalletClientModule {
pub(crate) root_secret: DerivableSecret,
pub(crate) cfg: WalletClientConfig,
pub(crate) notifier: ModuleNotifier<WalletClientStateMachines>,
pub(crate) client_ctx: ClientContext<Self>,
pub(crate) db: Database,
pub(crate) module_api: DynModuleApi,
}Fields
root_secret: DerivableSecretcfg: WalletClientConfignotifier: ModuleNotifier<WalletClientStateMachines>client_ctx: ClientContext<Self>db: Databasemodule_api: DynModuleApiImplementations
Sourceimpl WalletClientModule
impl WalletClientModule
Sourcepub fn get_network(&self) -> Network
pub fn get_network(&self) -> Network
Returns the Bitcoin network for this federation.
Sourcepub async fn total_value(&self) -> FederationResult<Amount>
pub async fn total_value(&self) -> FederationResult<Amount>
Fetch the total value of bitcoin controlled by the federation.
Sourcepub async fn block_count(&self) -> FederationResult<u64>
pub async fn block_count(&self) -> FederationResult<u64>
Fetch the consensus block count of the federation.
Sourcepub async fn feerate(&self) -> FederationResult<Option<u64>>
pub async fn feerate(&self) -> FederationResult<Option<u64>>
Fetch the current consensus feerate.
Sourcepub async fn pending_tx_chain(&self) -> FederationResult<Vec<TxInfo>>
pub async fn pending_tx_chain(&self) -> FederationResult<Vec<TxInfo>>
Fetch information on the chain of pending bitcoin transactions.
Sourcepub async fn tx_chain(&self) -> FederationResult<Vec<TxInfo>>
pub async fn tx_chain(&self) -> FederationResult<Vec<TxInfo>>
Display log of bitcoin transactions.
Sourcepub async fn send_fee(&self) -> Result<Amount, SendError>
pub async fn send_fee(&self) -> Result<Amount, SendError>
Fetch the current fee required to send an onchain payment.
Sourcepub async fn receive_fee(&self) -> Result<Amount>
pub async fn receive_fee(&self) -> Result<Amount>
Fetch the current fee required to claim an onchain deposit (peg-in).
Sourcepub async fn send(
&self,
address: Address<NetworkUnchecked>,
value: Amount,
fee: Option<Amount>,
custom_meta: Value,
) -> Result<OperationId, SendError>
pub async fn send( &self, address: Address<NetworkUnchecked>, value: Amount, fee: Option<Amount>, custom_meta: Value, ) -> Result<OperationId, SendError>
Send an onchain payment with the given fee.
Sourcepub async fn await_final_send_operation_state(
&self,
operation_id: OperationId,
) -> Result<FinalSendOperationState>
pub async fn await_final_send_operation_state( &self, operation_id: OperationId, ) -> Result<FinalSendOperationState>
Await the final state of the send operation.
Sourcepub async fn await_final_receive_operation_state(
&self,
operation_id: OperationId,
) -> Result<FinalReceiveOperationState>
pub async fn await_final_receive_operation_state( &self, operation_id: OperationId, ) -> Result<FinalReceiveOperationState>
Await the final state of the receive operation.
Sourcepub async fn receive(&self) -> Address
pub async fn receive(&self) -> Address
Returns the next unused receive address, polling until the initial address derivation has completed.
pub(crate) fn derive_address(&self, index: u64) -> Address
pub(crate) fn derive_tweak(&self, index: u64) -> Keypair
Sourcepub(crate) fn next_valid_index(&self, start_index: u64) -> u64
pub(crate) fn next_valid_index(&self, start_index: u64) -> u64
Find the next valid index starting from (and including) start_index.
Sourcepub(crate) async fn receive_output(
&self,
output_index: u64,
value: Amount,
address_index: u64,
fee: Amount,
outpoint: Option<OutPoint>,
) -> (OperationId, TransactionId)
pub(crate) async fn receive_output( &self, output_index: u64, value: Amount, address_index: u64, fee: Amount, outpoint: Option<OutPoint>, ) -> (OperationId, TransactionId)
Issue ecash for an unspent output with a given fee.
pub(crate) fn spawn_output_scanner( &self, task_group: &TaskGroup, client_span: &Span, )
pub(crate) async fn check_outputs(&self) -> Result<bool>